@@ -368,8 +368,8 @@ class API:
         data: dict[str, Any] = {}
         url = parse.urljoin(f"https://{host}", endpoint)
         if self.log_traces:
-            LOG.debug(f"RAW Headers: {kwargs['headers']}")
-            LOG.debug(f"RAW Async request: {method} {url}")
+            LOG.debug(f"[TRACE] Headers: {kwargs['headers']}")
+            LOG.debug(f"[TRACE] Async request: {method} {url}")
         async with self.session.request(method, url, **kwargs) as resp:
             if "application/json" in resp.headers.get("content-type", ""):
                 try:
@@ -381,11 +381,13 @@ class API:
             else:
                 data = {"message": await resp.text()}
             if self.log_traces:
-                LOG.debug("RAW Data received from /%s: %s", endpoint, data)
+                LOG.debug("[TRACE] Data received from /%s: %s", endpoint, data)
             resp.raise_for_status()
         return data
 
-    def _get_url(self, endpoint: str, location_id: int, gd: bool = False) -> str:
+    def _get_url(
+        self, endpoint: str, location_id: int, gd: bool = False, drms: bool = False
+    ) -> str:
         """Generate a path to the requested endpoint.
 
         :param endpoint: Path to the endpoint
@@ -394,12 +396,16 @@ class API:
         :type location_id: int
         :param gd: Whether or not we should use the GD Service endpoint, defaults to False
         :type gd: bool, optional
+        :param drms: Whether or not we should prepend the path with DRMS path, defaults to False
+        :type drms: bool, optional
         :return: Path to the requested endpoint
         :rtype: str
         """
         base = API_AUTOMATION_ENDPOINT
         if gd:
             base = API_GD_SERVICE_ENDPOINT
+        if drms:
+            base += "/DRMS"
         return base + "/Locations/" + str(location_id) + "/" + str(endpoint)
 
     async def _async_handle_on_backoff(self, _: dict[str, Any]) -> None:
@@ -671,26 +677,100 @@ class API:
         url = self._get_url(f"Devices/{device.id}/Attributes", device.location_id)
         await self.async_request("put", url, json={key.hilo_attribute: value})
 
-    async def get_events(self, location_id: int) -> dict[str, Any]:
-        url = f"{self._get_url('Events', location_id, True)}?active=true"
+    async def get_events(self, location_id: int, event_id: int = 0) -> dict[str, Any]:
+        """This will return either all the future challenges or details about a specific
+        challenge.
+        {
+          "currentPhase": null,
+          "parameters": {
+            "mode": "ambitious",
+            "devices": [
+              {
+                "id": xxx,
+                "deviceUid": "xxx",
+                "name": "Thermostat XXX",
+                "roomName": "Master bedroom",
+                "optOut": false,
+                "preheat": true
+              },
+          "consumption": {
+            "currentWh": 4548.9404,
+            "baselineWh": 14772.33,
+            "estimatedReward": null,
+            "baselineIntervals": [
+              {
+                "startTimeUtc": "2021-12-20T11:00:00Z",
+                "baselineWh": 3180.1558
+              },
+              {
+                "startTimeUtc": "2021-12-20T12:00:00Z",
+                "baselineWh": 3589.4753
+              },
+              {
+                "startTimeUtc": "2021-12-20T13:00:00Z",
+                "baselineWh": 4168.0957
+              },
+              {
+                "startTimeUtc": "2021-12-20T14:00:00Z",
+                "baselineWh": 3834.6038
+              }
+            ]
+          },
+          "isPreSeason": false,
+          "report": {
+            "status": "Success",
+            "reward": 5.63,
+            "isMissingBaseline": false,
+            "isMissingConsumption": false
+          },
+          "progress": "completed",
+          "isParticipating": true,
+          "isConfigurable": false,
+          "id": xxx,
+          "period": "am",
+          "phases": {
+            "preheatStartDateUTC": "2021-12-20T09:00:00Z",
+            "preheatEndDateUTC": "2021-12-20T11:00:00Z",
+            "reductionStartDateUTC": "2021-12-20T11:00:00Z",
+            "reductionEndDateUTC": "2021-12-20T15:00:00Z",
+            "recoveryStartDateUTC": "2021-12-20T15:00:00Z",
+            "recoveryEndDateUTC": "2021-12-20T15:50:00Z"
+          }
+        }
+        """
+
+        url = self._get_url("Events", location_id, True)
+        if not event_id:
+            url += "?active=true"
+        else:
+            url += f"/{event_id}"
+        return cast(dict[str, Any], await self.async_request("get", url))
+
+    async def get_seasons(self, location_id: int) -> dict[str, Any]:
+        """This will return the rewards and current season total
+        https://apim.hiloenergie.com/Automation/v1/api/DRMS/Locations/XXXX/Seasons
+        [
+          {
+            "season": 2021,
+            "totalReward": 69420.13,
+            "events": [
+              {
+                "id": 107,
+                "startDateUtc": "2021-11-25T20:00:00Z",
+                "period": "PM",
+                "reward": 8.77,
+                "status": "Success"
+              },
+            ]
+          }
+        ]
+        """
+        url = self._get_url("Seasons", location_id, drms=True)
         return cast(dict[str, Any], await self.async_request("get", url))
 
     async def get_gateway(self, location_id: int) -> dict[str, Any]:
         url = self._get_url("Gateways/Info", location_id)
         req = await self.async_request("get", url)
-        # [
-        #   {
-        #     "onlineStatus": "Online",
-        #     "lastStatusTimeUtc": "2021-11-08T01:43:15Z",
-        #     "zigBeePairingActivated": false,
-        #     "dsn": "xxx",
-        #     "installationCode": "xxx",
-        #     "sepMac": "xxx",
-        #     "firmwareVersion": "2.1.2",
-        #     "localIp": null,
-        #     "zigBeeChannel": 19
-        #   }
-        # ]
         saved_attrs = [
             "zigBeePairingActivated",
             "zigBeeChannel",
